# PWE-NB-Extension
Notebook Extension for PWE

#### Acknowledgement:
Prolog Syntax Highlighting code for Codemirror found [here](https://github.com/SWI-Prolog/swish/tree/master/web/js/codemirror/mode/prolog)
